==> dss-spi-6.0-sources.jar: eu/europa/esig/dss/spi/x509/tsp/TimestampCertificateSource.java <==
/**
 * DSS - Digital Signature Services
 * Copyright (C) 2015 European Commission, provided under the CEF programme
 * 
 * This file is part of the "DSS - Digital Signature Services" project.
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package eu.europa.esig.dss.spi.x509.tsp;

import eu.europa.esig.dss.enumerations.CertificateSourceType;
import eu.europa.esig.dss.spi.DSSASN1Utils;
import eu.europa.esig.dss.spi.x509.CMSCertificateSource;
import org.bouncycastle.tsp.TimeStampToken;

/**
 * A timestamp CMS certificate source
 *
 */
@SuppressWarnings("serial")
public class TimestampCertificateSource extends CMSCertificateSource {

	/**
	 * Default constructor
	 *
	 * @param timestampToken {@link TimeStampToken}
	 */
	public TimestampCertificateSource(final TimeStampToken timestampToken) {
		super(timestampToken.toCMSSignedData(), DSSASN1Utils.getFirstSignerInformation(timestampToken.toCMSSignedData()));
	}

	@Override
	public CertificateSourceType getCertificateSourceType() {
		return CertificateSourceType.TIMESTAMP;
	}

}

==> dss-spi-6.3-sources.jar: eu/europa/esig/dss/spi/x509/tsp/TimestampCertificateSource.java <==
/**
 * DSS - Digital Signature Services
 * Copyright (C) 2015 European Commission, provided under the CEF programme
 * <p>
 * This file is part of the "DSS - Digital Signature Services" project.
 * <p>
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * <p>
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * <p>
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package eu.europa.esig.dss.spi.x509.tsp;

import eu.europa.esig.dss.enumerations.CertificateSourceType;
import eu.europa.esig.dss.spi.DSSASN1Utils;
import eu.europa.esig.dss.spi.x509.CMSCertificateSource;
import org.bouncycastle.tsp.TimeStampToken;

/**
 * A timestamp CMS certificate source
 *
 */
@SuppressWarnings("serial")
public class TimestampCertificateSource extends CMSCertificateSource {

	/**
	 * Default constructor
	 *
	 * @param timestampToken {@link TimeStampToken}
	 */
	public TimestampCertificateSource(final TimeStampToken timestampToken) {
		super(timestampToken.toCMSSignedData().getSignerInfos(), timestampToken.getCertificates(),
				DSSASN1Utils.getFirstSignerInformation(timestampToken.toCMSSignedData().getSignerInfos()));
	}

	@Override
	public CertificateSourceType getCertificateSourceType() {
		return CertificateSourceType.TIMESTAMP;
	}

}
